# Julia-distribution

In this package I've written a code to calculate the Binominal und Gaussian distribution.

# Files

The Files included here are:
1. Binominaldistribution.py
	Calcualation of Binominal distribution
2. Gaussiandistribution.py
	Calculation of Gaussian distribution
3. Generaldistribution.py
	Class Distribuiton
4. __init__.py
5. license.txt
	license
6. setup.py
	setup
7. setup.cfg

# Insatllation

you only need the normal packages of Python 3.*

# licensing

Parts of the code I got from Udicity for my Nanodegree Data Science. Otherwise feel free to use the code as you wish.

